@@ -1,10 +1,11 @@
-from typing import Set
+from typing import Iterator, Set
 
 import pandas as pd
 from cartopy.crs import PlateCarree
 from cartopy.mpl.geoaxes import GeoAxesSubplot
 from matplotlib.artist import Artist
 
+from .flight import Position
 from .mixins import GeographyMixin
 
 
@@ -25,6 +26,14 @@ class StateVectors(GeographyMixin):
     def callsigns(self):
         return set(self.data.callsign)
 
+    def __iter__(self) -> Iterator[Position]:
+        for _, p in self.data.assign(
+            # let's keep this name for now
+            name=self.data.callsign
+        ).iterrows():
+            # TODO work on a clean __repr__ for the Position
+            yield Position(p)
+
     def plot(
         self, ax: GeoAxesSubplot, s: int = 10, **kwargs
     ) -> Artist:  # coverage: ignore
