@@ -211,7 +211,7 @@ class OpenSky(Impala):
 
         return StateVectors(r, self)
 
-    def api_tracks(self, icao24: str) -> Flight:
+    def api_tracks(self, icao24: str, time: Optional[timelike] = None) -> Flight:
         """Returns a Flight corresponding to a given aircraft.
 
         Official documentation
@@ -245,8 +245,9 @@ class OpenSky(Impala):
         detailed track information.
 
         """
+        time = int(to_datetime(time).timestamp()) if time is not None else 0
         c = self.session.get(
-            f"https://opensky-network.org/api/tracks/?icao24={icao24}"
+            f"https://opensky-network.org/api/tracks/?icao24={icao24}&time={time}"
         )
         c.raise_for_status()
         json = c.json()
