@@ -1,28 +1,49 @@
-from typing import Any, Callable, Dict, Iterable, List, Optional
+# fmt: off
 
-from ipyleaflet import Map, Marker, Polygon, Polyline
+from typing import Any, Callable, Dict, Iterable, List, Optional, Union
+
+from ipyleaflet import GeoData, Map, Marker, MarkerCluster, Polygon, Polyline
 from ipywidgets import HTML
 from shapely.geometry import LineString
 
-from ..core import Airspace, Flight, FlightIterator, FlightPlan, Traffic
+from ..core import (
+    Airspace, Flight, FlightIterator, FlightPlan, StateVectors, Traffic
+)
 from ..core.mixins import PointMixin
+from ..core.structure import Airport
+
+# fmt: on
 
 
 def traffic_map_leaflet(
     traffic: "Traffic",
+    *,
     zoom: int = 7,
-    highlight: Optional[Dict[str, Callable[[Flight], Optional[Flight]]]] = None,
+    highlight: Optional[
+        Dict[str, Union[str, Flight, Callable[[Flight], Optional[Flight]]]]
+    ] = None,
+    airport: Union[None, str, Airport] = None,
     **kwargs,
 ) -> Optional[Map]:
 
+    from traffic.data import airports
+
+    _airport = airports[airport] if isinstance(airport, str) else airport
+
     if "center" not in kwargs:
-        kwargs["center"] = (
-            traffic.data.latitude.mean(),
-            traffic.data.longitude.mean(),
-        )
+        if _airport is not None:
+            kwargs["center"] = _airport.latlon
+        else:
+            kwargs["center"] = (
+                traffic.data.latitude.mean(),
+                traffic.data.longitude.mean(),
+            )
 
     m = Map(zoom=zoom, **kwargs)
 
+    if _airport is not None:
+        m.add_layer(_airport)
+
     for flight in traffic:
         if flight.query("latitude == latitude"):
             elt = m.add_layer(flight)
@@ -32,8 +53,17 @@ def traffic_map_leaflet(
         if highlight is None:
             highlight = dict()
 
-        for color, method in highlight.items():
-            f = method(flight)
+        for color, value in highlight.items():
+            if isinstance(value, str):
+                value = getattr(Flight, value, None)
+                if value is None:
+                    continue
+            assert not isinstance(value, str)
+            f: Optional[Flight]
+            if isinstance(value, Flight):
+                f = value
+            else:
+                f = value(flight)
             if f is not None:
                 m.add_layer(f, color=color)
 
@@ -42,16 +72,40 @@ def traffic_map_leaflet(
 
 def flight_map_leaflet(
     flight: "Flight",
+    *,
     zoom: int = 7,
-    highlight: Optional[Dict[str, Callable[[Flight], Optional[Flight]]]] = None,
+    highlight: Optional[
+        Dict[
+            str,
+            Union[str, Flight, Callable[[Flight], Optional[Flight]]],
+        ]
+    ] = None,
+    airport: Union[None, str, Airport] = None,
     **kwargs,
 ) -> Optional[Map]:
     from traffic.core import Flight
+    from traffic.data import airports
 
     last_position = flight.query("latitude == latitude").at()  # type: ignore
     if last_position is None:
         return None
-    m = Map(center=last_position.latlon, zoom=zoom, **kwargs)
+
+    _airport = airports[airport] if isinstance(airport, str) else airport
+
+    if "center" not in kwargs:
+        if _airport is not None:
+            kwargs["center"] = _airport.latlon
+        else:
+            kwargs["center"] = (
+                flight.data.latitude.mean(),
+                flight.data.longitude.mean(),
+            )
+
+    m = Map(zoom=zoom, **kwargs)
+
+    if _airport is not None:
+        m.add_layer(_airport)
+
     elt = m.add_layer(flight)
     elt.popup = HTML()
     elt.popup.value = flight._info_html()
@@ -59,12 +113,17 @@ def flight_map_leaflet(
     if highlight is None:
         highlight = dict()
 
-    for color, method in highlight.items():
-        if isinstance(method, str):
-            method = getattr(Flight, method, None)
-            if method is None:
+    for color, value in highlight.items():
+        if isinstance(value, str):
+            value = getattr(Flight, value, None)
+            if value is None:
                 continue
-        f = method(flight)
+        assert not isinstance(value, str)
+        f: Optional[Flight]
+        if isinstance(value, Flight):
+            f = value
+        else:
+            f = value(flight)
         if f is not None:
             m.add_layer(f, color=color)
 
@@ -152,6 +211,28 @@ def airspace_leaflet(airspace: "Airspace", **kwargs) -> Polygon:
     return Polygon(locations=coords, **kwargs)
 
 
+def airport_leaflet(airport: "Airport", **kwargs) -> GeoData:
+    return GeoData(
+        geo_dataframe=airport._openstreetmap()
+        .query('aeroway == "runway"')
+        .data,
+        style={**{"color": "#79706e", "weight": 6}, **kwargs},
+    )
+
+
+def sv_leaflet(sv: "StateVectors", **kwargs) -> MarkerCluster:
+    """Returns a Leaflet layer to be directly added to a Map.
+
+    .. warning::
+        This is only available if the Leaflet `plugin <plugins.html>`_ is
+        activated. (true by default)
+
+    The elements passed as kwargs as passed as is to the Marker constructor.
+    """
+    point_list = list(point_leaflet(p, title=p.callsign, **kwargs) for p in sv)
+    return MarkerCluster(markers=point_list)
+
+
 def point_leaflet(point: "PointMixin", **kwargs) -> Marker:
     """Returns a Leaflet layer to be directly added to a Map.
 
@@ -164,7 +245,7 @@ def point_leaflet(point: "PointMixin", **kwargs) -> Marker:
 
     default = dict()
     if hasattr(point, "name"):
-        default["title"] = point.name
+        default["title"] = str(point.name)
 
     kwargs = {**default, **kwargs}
     marker = Marker(location=(point.latitude, point.longitude), **kwargs)
@@ -181,7 +262,15 @@ _old_add_layer = Map.add_layer
 
 def map_add_layer(_map, elt, **kwargs):
     if any(
-        isinstance(elt, c) for c in (Flight, FlightPlan, Airspace, PointMixin)
+        isinstance(elt, c)
+        for c in (
+            Airport,
+            Airspace,
+            Flight,
+            FlightPlan,
+            PointMixin,
+            StateVectors,
+        )
     ):
         layer = elt.leaflet(**kwargs)
         _old_add_layer(_map, layer)
@@ -194,10 +283,14 @@ def map_add_layer(_map, elt, **kwargs):
 
 
 def _onload():
+    setattr(Airport, "leaflet", airport_leaflet)
+    setattr(Airspace, "leaflet", airspace_leaflet)
     setattr(Flight, "leaflet", flight_leaflet)
+    setattr(FlightPlan, "leaflet", flightplan_leaflet)
+    setattr(PointMixin, "leaflet", point_leaflet)
+    setattr(StateVectors, "leaflet", sv_leaflet)
+
     setattr(Flight, "map_leaflet", flight_map_leaflet)
     setattr(Traffic, "map_leaflet", traffic_map_leaflet)
-    setattr(FlightPlan, "leaflet", flightplan_leaflet)
-    setattr(Airspace, "leaflet", airspace_leaflet)
-    setattr(PointMixin, "leaflet", point_leaflet)
+
     setattr(Map, "add_layer", map_add_layer)
